@@ -32,6 +32,10 @@ use std::matches;
 use std::path::Path;
 use std::path::PathBuf;
 use std::process;
+#[cfg(feature = "viewer")]
+use std::thread;
+#[cfg(feature = "viewer")]
+use std::time::Duration;
 use tera::Value;
 
 /// Open the note file `path` on disk and reads its YAML front matter.
@@ -335,6 +339,11 @@ pub fn run() -> Result<PathBuf, WorkflowError> {
     };
 
     if *LAUNCH_EDITOR {
+        #[cfg(feature = "viewer")]
+        if viewer_join_handle.is_some() && CFG.viewer.startup_delay < 0 {
+            thread::sleep(Duration::from_millis(CFG.viewer.startup_delay.abs() as u64));
+        };
+
         // This blocks.
         launch_editor(&path)?;
     };
